@@ -1,8 +1,8 @@
 from email.mime.image import MIMEImage
-from email.utils import unquote
+from email.utils import make_msgid, unquote
 from pathlib import Path
 
-from django.core.mail import EmailMessage, EmailMultiAlternatives, make_msgid
+from django.core.mail import EmailMessage, EmailMultiAlternatives
 
 from .utils import UNSET
 
@@ -29,6 +29,7 @@ class AnymailMessageMixin(EmailMessage):
         self.template_id = kwargs.pop("template_id", UNSET)
         self.merge_data = kwargs.pop("merge_data", UNSET)
         self.merge_global_data = kwargs.pop("merge_global_data", UNSET)
+        self.merge_headers = kwargs.pop("merge_headers", UNSET)
         self.merge_metadata = kwargs.pop("merge_metadata", UNSET)
         self.anymail_status = AnymailStatus()
 
